package com.syntevo.plugin.removeemptydirectories;

import com.syntevo.openapi.smartsvn.action.*;
import com.syntevo.openapi.smartsvn.file.*;
import com.syntevo.openapi.smartsvn.file.gui.*;

/**
 * @author syntevo GmbH
 */
final class REDFileDirectoryAction implements ISvnFileDirectoryAction {

	// Constants ==============================================================

	public static final String ID = RemoveEmptyDirectoriesPlugin.ID + ".RemoveEmptyDirectories";

	// Setup ==================================================================

	public REDFileDirectoryAction() {
	}

	// Implemented ============================================================

	public boolean isApplicable(SelectedSvnFiles selectedFiles, SelectedSvnDirectories selectedDirectories) {
		final SvnDirectory directory = selectedDirectories.getDirectory();
		if (directory == null) {
			return false;
		}

		final SvnDirectoryLocalState state = directory.getLocalState();
		return state == SvnDirectoryLocalState.CONFLICT
				|| state == SvnDirectoryLocalState.COPIED
				|| state == SvnDirectoryLocalState.HISTORY_SCHEDULED
				|| state == SvnDirectoryLocalState.NESTED_ROOT
				|| state == SvnDirectoryLocalState.MODIFIED
				|| state == SvnDirectoryLocalState.UNCHANGED;
	}

	public void execute(SelectedSvnFiles files, SvnEntryQuery entryQuery, ActionServices services) {
		throw new UnsupportedOperationException();
	}

	public void execute(SelectedSvnDirectories directories, SvnEntryQuery entryQuery, ActionServices services) {
		if (!services.getDialogDisplayer().showConfirmationDialog("Remove Empty Directories", "Do you want to start searching for empty directories?",
		                                                          "Found empty directories will be marked for removal.", "Start", false)) {
			return;
		}

		services.scheduleCommand(new REDSvnCommand(directories.getDirectory()), "Remove Empty Directories");
	}
}
